@@ -39,7 +39,9 @@ pVoice(0),
   
   CodePage = GetUserCodePage();
   m_Font = GetCodePageFont(CodePage, 14);
- 
+
+  // FIXME - move speech into a new file
+
   // Initialise speech support
   speech.resize(0);
 
@@ -59,14 +61,16 @@ pVoice(0),
 
 ////////////////////////////////////////////////////////////////////////////
 
-HWND CEdit::Create(HWND hParent)
+HWND CEdit::Create(HWND hParent, bool bNewWithDate)
 {
 	HWND hWnd = CWindowImpl<CEdit>::Create(hParent, NULL, NULL, ES_NOHIDESEL | WS_CHILD | ES_MULTILINE | WS_VSCROLL | WS_VISIBLE, WS_EX_CLIENTEDGE);
 
 	
 	Tstring WindowTitle;
 	WinLocalisation::GetResourceString(IDS_APP_TITLE, &WindowTitle);
-	m_FilenameGUI = new CFilenameGUI(hParent, WindowTitle.c_str());
+	m_FilenameGUI = new CFilenameGUI(hParent, WindowTitle.c_str(), bNewWithDate);
+
+  m_filename = m_FilenameGUI->GetFilename();
 
 	return hWnd;
 }
@@ -223,6 +227,28 @@ void CEdit::TimeStampNewFiles(bool Value) {
   m_FilenameGUI->SetNewWithDate(Value);
 }
 
+bool CEdit::QueryClose() {
+  switch (m_FilenameGUI->QuerySaveFirst()) {
+  case IDYES:
+    if(!Save()) {
+      if(!TSaveAs(m_FilenameGUI->SaveAs()))
+        return false;
+      else
+        return true;
+    }
+    else {
+      return true;
+    }
+    break;
+  case IDNO:
+    return true;
+    break;
+  default:
+    return false;
+    break;
+  }
+}
+
 void CEdit::New() {
   switch (m_FilenameGUI->QuerySaveFirst()) {
   case IDYES:
@@ -842,8 +868,10 @@ LRESULT CEdit::OnLButtonUp(UINT message, WPARAM wParam, LPARAM lParam, BOOL& bHa
 	// DJW20060101 - I put the following line back in, and it half-works
 	// The Dasher display resets to the root context, rather than pulling the
 	// context from the edit control
-	m_pDasherInterface->ChangeEdit();
-    InvalidateRect(NULL, FALSE);
+//	m_pDasherInterface->ChangeEdit();
+  //  InvalidateRect(NULL, FALSE);
+
+  m_pDasherInterface->InvalidateContext();
 
 	bHandled = FALSE; // let the EDIT class handle it
 	return 0;
@@ -1193,3 +1221,30 @@ void CEdit::speak(int what) {
 
 #endif
 }
+
+void CEdit::SetNewWithDate(bool bNewWithDate) {
+  if(m_FilenameGUI)
+    m_FilenameGUI->SetNewWithDate(bNewWithDate);
+}
+
+std::string CEdit::GetContext(int iLength) {
+  LRESULT lResult(SendMessage(m_hWnd, EM_GETHANDLE, 0, 0));
+  HLOCAL hMemoryHandle((HLOCAL)lResult);
+
+  int iOffset;
+  SendMessage(m_hWnd, EM_GETSEL, (WPARAM)&iOffset, 0);
+
+  int iStart(iOffset - iLength);
+
+  if(iStart < 0)
+    iStart = 0;
+
+  LPVOID pBuffer(LocalLock(hMemoryHandle));
+  std::wstring strContext((TCHAR *)pBuffer + iStart, iOffset - iStart);
+  LocalUnlock(hMemoryHandle);
+
+  std::string strReturnValue;
+  WinUTF8::wstring_to_UTF8string(strContext, strReturnValue);
+
+  return strReturnValue;
+}
\ No newline at end of file
